@@ -5,8 +5,9 @@
 use strict;
 
 use Data::Dumper;
-use Inline Config => force_build => 1,
-  print_info      => 1;
+use Inline Config => 
+  force_build => 1,
+  print_info  => 1;
 use Graphics::Framebuffer;
 $Data::Dumper::Sortkeys = 1;
 my $dev = 0;
