@@ -49,24 +49,25 @@ our $DB = 0;
 our $STAMP = sprintf('%.1', time);
 
 if (defined($new_x)) {
-    $FR = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'SHOW_ERRORS' => 0, 'SIMULATED_X' => $new_x, 'SIMULATED_Y' => $new_y, 'SPLASH' => 0);
+    ($FR,$F) = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'SHOW_ERRORS' => 0, 'SIMULATED_X' => $new_x, 'SIMULATED_Y' => $new_y, 'DOUBLE_BUFFER' => 1);
 } else {
-    $FR = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'SHOW_ERRORS' => 0, 'SPLASH' => 0);
+    ($FR,$F) = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'SHOW_ERRORS' => 0,'DOUBLE_BUFFER'=>1);
 }
-
+# warn "PHYSICAL: " . $FR->{'COLOR_ORDER'} . "\nVIRTUAL: " . $F->{'COLOR_ORDER'} . "\n\n";sleep 10;
 $FR->cls('OFF');
 
 my $sinfo = $FR->screen_dimensions;
 
 # If 16 bit mode and acceleration is supported, then do double-buffering
+
 if ($sinfo->{'bits_per_pixel'} == 16 && $FR->{'ACCELERATED'}) {
-    $F = Graphics::Framebuffer->new('FB_DEVICE' => 'virtual', 'SHOW_ERRORS' => 1, 'SPLASH' => 0, 'VXRES' => $sinfo->{'width'}, 'VYRES' => $sinfo->{'height'}, 'COLOR_ORDER' => $sinfo->{'color_order'});
     $F->{'fscreeninfo'}->{'id'} = $FR->{'fscreeninfo'}->{'id'};
     $DB = 1;
-} else {
+} else { # Don't need double buffering for 32 bit or unaccelerated 16 bit
     $F = $FR;
 }
 
+
 my $screen_width  = $sinfo->{'width'};
 my $screen_height = $sinfo->{'height'};
 
@@ -140,7 +141,7 @@ $F->cls('OFF');
 $DIRTY = 1;    # Set this to signal the buffer needs flipping
 sleep 4;
 
-# if (0) { # This line only used for debugging
+ if (0) { # This line only used for debugging
 color_mapping();
 plotting();
 foreach my $flag (0 .. 1) {
@@ -197,7 +198,7 @@ color_replace_no_clipping();
 
 blitting();
 blit_move();
-rotate();
+rotate();}
 flipping();
 monochrome();
 foreach my $m (1 .. 9) {    # We skip divide mode because it's stupid and I should never have added it
@@ -1329,16 +1330,15 @@ sub rotate {
 } ## end sub rotate
 
 sub flipping {
-    my $image = $IMAGES[int(rand(scalar(@IMAGES)))];
+    my $image = { %{ $IMAGES[int(rand(scalar(@IMAGES)))] } };
 
     $image->{'y'} = $F->{'Y_CLIP'};
     my $s    = time + $factor * 2;
     my $zoom = time + $factor;
     while (time < $s) {
-
-        #        foreach my $dir (qw(normal vertical horizontal)) {
         foreach my $dir (qw(normal horizontal vertical both)) {
-            my $rot = $F->blit_transform(
+            print_it($F, "Testing Image Flip $dir");
+            my $rot = ($dir eq 'normal') ? $image : $F->blit_transform(
                 {
                     'flip'      => $dir,
                     'blit_data' => $image
@@ -1346,10 +1346,9 @@ sub flipping {
             );
             $rot->{'x'} = abs(($XX - $rot->{'width'}) / 2);
             $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
-            print_it($F, "Testing Image Flip $dir");
             $F->blit_write($rot);
             $DIRTY = 1;
-
+            
             if (time < $zoom) {
                 sleep .3;
             } else {
@@ -1458,7 +1457,7 @@ sub animated {
 sub mode_drawing {
     my $mode  = shift;
     my @modes = qw( NORMAL XOR OR AND MASK UNMASK ALPHA ADD SUBTRACT MULTIPLY DIVIDE );
-    print_it($F, 'Testing ' . $modes[$mode] . ' Drawing Mode');
+    print_it($F, 'Testing "' . $modes[$mode] . '" Drawing Mode');
     my $image = $IMAGES[int(rand(scalar(@IMAGES)))];
     my $image2;
     do {
