@@ -19,8 +19,6 @@ my @a    = @ARGV;
 my $path = pop(@a);
 my $args = join('', @a);
 
-my $file = 0;
-$file = 1 if ($args =~ /file/i);
 my $errors = 0;
 $errors = 1 if ($args =~ /errors/i);
 my $auto = 0;
@@ -43,13 +41,13 @@ $SIG{'QUIT'} = sub {
     print STDERR "\nExiting..\n";
     $RUNNING = 0;
     sleep 1;
-    $SIG{'QUIT'} = sub { exit(1); };
+    $SIG{'QUIT'} = sub { exec('reset'); };
 };
 $SIG{'INT'} = sub {
     print STDERR "\nExiting..\n";
     $RUNNING = 0;
     sleep 1;
-    $SIG{'INT'} = sub { exit(1); };
+    $SIG{'INT'} = sub { exec('reset'); };
 };
 
 our @pics;
@@ -62,7 +60,7 @@ foreach my $fb (@fbs) {
             'FB_DEVICE'   => $fb,
             'SPLASH'      => 0,
             'SHOW_ERRORS' => $errors,
-            'FILE_MODE'   => $file
+            'RESET'       => 0,
         )
     );
 } ## end foreach my $fb (@fbs)
