@@ -11,9 +11,6 @@ use Time::HiRes qw(sleep time);
 
 # use Data::Dumper::Simple;$Data::Dumper::Sortkeys=1;
 
-$SIG{'QUIT'} = sub { exec('reset'); };
-$SIG{'INT'}  = sub { exec('reset'); };
-
 my @a    = @ARGV;
 my $file = pop(@a);
 
@@ -21,9 +18,6 @@ my $args = join('', @a);
 my $full = 0;
 $full = 1 if ($args =~ /full/i);
 
-my $file = 0;
-$file = 1 if ($args =~ /file/i);
-
 my $dev = 0;
 if ($args =~ /(\d+)/) {
     ($dev) = $1;
@@ -33,7 +27,6 @@ my $f = Graphics::Framebuffer->new(
     'FB_DEVICE'   => "/dev/fb$dev",
     'SPLASH'      => 0,
     'SHOW_ERRORS' => 1,
-    'FILE_MODE'   => $file
 );
 
 system('clear');
